==> ansible-3.1.0-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_wtpprofile_lbs.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2020 Fortinet, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_wtpprofile_lbs
short_description: Set various location based service (LBS) options.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.10"
author:
    - Link Zheng (@chillancezen)
    - Jie Xue (@JieX19)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded

options:
    bypass_validation:
        description: only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters
        required: false
        type: bool
        default: false
    workspace_locking_adom:
        description: the adom to lock for FortiManager running in workspace mode, the value can be global and others including root
        required: false
        type: str
    workspace_locking_timeout:
        description: the maximum time in seconds to wait for other user to release the workspace lock
        required: false
        type: int
        default: 300
    state:
        description: the directive to create, update or delete an object
        type: str
        required: true
        choices:
          - present
          - absent
    rc_succeeded:
        description: the rc codes list with which the conditions to succeed will be overriden
        type: list
        required: false
    rc_failed:
        description: the rc codes list with which the conditions to fail will be overriden
        type: list
        required: false
    adom:
        description: the parameter (adom) in requested url
        type: str
        required: true
    wtp-profile:
        description: the parameter (wtp-profile) in requested url
        type: str
        required: true
    wtpprofile_lbs:
        description: the top level parameters set
        required: false
        type: dict
        suboptions:
            aeroscout:
                type: str
                description: 'Enable/disable AeroScout Real Time Location Service (RTLS) support.'
                choices:
                    - 'disable'
                    - 'enable'
            aeroscout-ap-mac:
                type: str
                description: 'Use BSSID or board MAC address as AP MAC address in the Aeroscout AP message.'
                choices:
                    - 'bssid'
                    - 'board-mac'
            aeroscout-mmu-report:
                type: str
                description: 'Enable/disable MU compounded report.'
                choices:
                    - 'disable'
                    - 'enable'
            aeroscout-mu:
                type: str
                description: 'Enable/disable AeroScout support.'
                choices:
                    - 'disable'
                    - 'enable'
            aeroscout-mu-factor:
                type: int
                description: 'AeroScout Mobile Unit (MU) mode dilution factor (default = 20).'
            aeroscout-mu-timeout:
                type: int
                description: 'AeroScout MU mode timeout (0 - 65535 sec, default = 5).'
            aeroscout-server-ip:
                type: str
                description: 'IP address of AeroScout server.'
            aeroscout-server-port:
                type: int
                description: 'AeroScout server UDP listening port.'
            ekahau-blink-mode:
                type: str
                description: 'Enable/disable Ekahua blink mode (also called AiRISTA Flow Blink Mode) to find the location of devices connected to a wireless...'
                choices:
                    - 'disable'
                    - 'enable'
            ekahau-tag:
                type: str
                description: 'WiFi frame MAC address or WiFi Tag.'
            erc-server-ip:
                type: str
                description: 'IP address of Ekahua RTLS Controller (ERC).'
            erc-server-port:
                type: int
                description: 'Ekahua RTLS Controller (ERC) UDP listening port.'
            fortipresence:
                type: str
                description: 'Enable/disable FortiPresence to monitor the location and activity of WiFi clients even if they dont connect to this WiFi netwo...'
                choices:
                    - 'disable'
                    - 'enable'
                    - 'enable2'
                    - 'foreign'
                    - 'both'
            fortipresence-frequency:
                type: int
                description: 'FortiPresence report transmit frequency (5 - 65535 sec, default = 30).'
            fortipresence-port:
                type: int
                description: 'FortiPresence server UDP listening port (default = 3000).'
            fortipresence-project:
                type: str
                description: 'FortiPresence project name (max. 16 characters, default = fortipresence).'
            fortipresence-rogue:
                type: str
                description: 'Enable/disable FortiPresence finding and reporting rogue APs.'
                choices:
                    - 'disable'
                    - 'enable'
            fortipresence-secret:
                description: no description
                type: str
            fortipresence-server:
                type: str
                description: 'FortiPresence server IP address.'
            fortipresence-unassoc:
                type: str
                description: 'Enable/disable FortiPresence finding and reporting unassociated stations.'
                choices:
                    - 'disable'
                    - 'enable'
            station-locate:
                type: str
                description: 'Enable/disable client station locating services for all clients, whether associated or not (default = disable).'
                choices:
                    - 'disable'
                    - 'enable'

'''

EXAMPLES = '''
 - hosts: fortimanager-inventory
   collections:
     - fortinet.fortimanager
   connection: httpapi
   vars:
      ansible_httpapi_use_ssl: True
      ansible_httpapi_validate_certs: False
      ansible_httpapi_port: 443
   tasks:
    - name: Set various location based service (LBS) options.
      fmgr_wtpprofile_lbs:
         bypass_validation: False
         workspace_locking_adom: <value in [global, custom adom including root]>
         workspace_locking_timeout: 300
         rc_succeeded: [0, -2, -3, ...]
         rc_failed: [-2, -3, ...]
         adom: <your own value>
         wtp-profile: <your own value>
         wtpprofile_lbs:
            aeroscout: <value in [disable, enable]>
            aeroscout-ap-mac: <value in [bssid, board-mac]>
            aeroscout-mmu-report: <value in [disable, enable]>
            aeroscout-mu: <value in [disable, enable]>
            aeroscout-mu-factor: <value of integer>
            aeroscout-mu-timeout: <value of integer>
            aeroscout-server-ip: <value of string>
            aeroscout-server-port: <value of integer>
            ekahau-blink-mode: <value in [disable, enable]>
            ekahau-tag: <value of string>
            erc-server-ip: <value of string>
            erc-server-port: <value of integer>
            fortipresence: <value in [disable, enable, enable2, ...]>
            fortipresence-frequency: <value of integer>
            fortipresence-port: <value of integer>
            fortipresence-project: <value of string>
            fortipresence-rogue: <value in [disable, enable]>
            fortipresence-secret: <value of string>
            fortipresence-server: <value of string>
            fortipresence-unassoc: <value in [disable, enable]>
            station-locate: <value in [disable, enable]>

'''

RETURN = '''
request_url:
    description: The full url requested
    returned: always
    type: str
    sample: /sys/login/user
response_code:
    description: The status of api request
    returned: always
    type: int
    sample: 0
response_message:
    description: The descriptive message of the api response
    type: str
    returned: always
    sample: OK.

'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass


def main():
    jrpc_urls = [
        '/pm/config/adom/{adom}/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs',
        '/pm/config/global/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs'
    ]

    perobject_jrpc_urls = [
        '/pm/config/adom/{adom}/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs/{lbs}',
        '/pm/config/global/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs/{lbs}'
    ]

    url_params = ['adom', 'wtp-profile']
    module_primary_key = None
    module_arg_spec = {
        'bypass_validation': {
            'type': 'bool',
            'required': False,
            'default': False
        },
        'workspace_locking_adom': {
            'type': 'str',
            'required': False
        },
        'workspace_locking_timeout': {
            'type': 'int',
            'required': False,
            'default': 300
        },
        'rc_succeeded': {
            'required': False,
            'type': 'list'
        },
        'rc_failed': {
            'required': False,
            'type': 'list'
        },
        'adom': {
            'required': True,
            'type': 'str'
        },
        'wtp-profile': {
            'required': True,
            'type': 'str'
        },
        'wtpprofile_lbs': {
            'required': False,
            'type': 'dict',
            'options': {
                'aeroscout': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'aeroscout-ap-mac': {
                    'required': False,
                    'choices': [
                        'bssid',
                        'board-mac'
                    ],
                    'type': 'str'
                },
                'aeroscout-mmu-report': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'aeroscout-mu': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'aeroscout-mu-factor': {
                    'required': False,
                    'type': 'int'
                },
                'aeroscout-mu-timeout': {
                    'required': False,
                    'type': 'int'
                },
                'aeroscout-server-ip': {
                    'required': False,
                    'type': 'str'
                },
                'aeroscout-server-port': {
                    'required': False,
                    'type': 'int'
                },
                'ekahau-blink-mode': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'ekahau-tag': {
                    'required': False,
                    'type': 'str'
                },
                'erc-server-ip': {
                    'required': False,
                    'type': 'str'
                },
                'erc-server-port': {
                    'required': False,
                    'type': 'int'
                },
                'fortipresence': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable',
                        'enable2',
                        'foreign',
                        'both'
                    ],
                    'type': 'str'
                },
                'fortipresence-frequency': {
                    'required': False,
                    'type': 'int'
                },
                'fortipresence-port': {
                    'required': False,
                    'type': 'int'
                },
                'fortipresence-project': {
                    'required': False,
                    'type': 'str'
                },
                'fortipresence-rogue': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'fortipresence-secret': {
                    'required': False,
                    'type': 'str'
                },
                'fortipresence-server': {
                    'required': False,
                    'type': 'str'
                },
                'fortipresence-unassoc': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'station-locate': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                }
            }

        }
    }

    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'wtpprofile_lbs'),
                           supports_check_mode=False)

    fmgr = None
    if module._socket_path:
        connection = Connection(module._socket_path)
        fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
        fmgr.validate_parameters(params_validation_blob)
        fmgr.process_partial_curd()
    else:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-4.1.0-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_wtpprofile_lbs.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2021 Fortinet, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_wtpprofile_lbs
short_description: Set various location based service (LBS) options.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.10"
author:
    - Link Zheng (@chillancezen)
    - Jie Xue (@JieX19)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded

options:
    enable_log:
        description: Enable/Disable logging for task
        required: false
        type: bool
        default: false
    proposed_method:
        description: The overridden method for the underlying Json RPC request
        required: false
        type: str
        choices:
          - update
          - set
          - add
    bypass_validation:
        description: only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters
        required: false
        type: bool
        default: false
    workspace_locking_adom:
        description: the adom to lock for FortiManager running in workspace mode, the value can be global and others including root
        required: false
        type: str
    workspace_locking_timeout:
        description: the maximum time in seconds to wait for other user to release the workspace lock
        required: false
        type: int
        default: 300
    state:
        description: the directive to create, update or delete an object
        type: str
        required: true
        choices:
          - present
          - absent
    rc_succeeded:
        description: the rc codes list with which the conditions to succeed will be overriden
        type: list
        required: false
    rc_failed:
        description: the rc codes list with which the conditions to fail will be overriden
        type: list
        required: false
    adom:
        description: the parameter (adom) in requested url
        type: str
        required: true
    wtp-profile:
        description: the parameter (wtp-profile) in requested url
        type: str
        required: true
    wtpprofile_lbs:
        description: the top level parameters set
        required: false
        type: dict
        suboptions:
            aeroscout:
                type: str
                description: 'Enable/disable AeroScout Real Time Location Service (RTLS) support.'
                choices:
                    - 'disable'
                    - 'enable'
            aeroscout-ap-mac:
                type: str
                description: 'Use BSSID or board MAC address as AP MAC address in the Aeroscout AP message.'
                choices:
                    - 'bssid'
                    - 'board-mac'
            aeroscout-mmu-report:
                type: str
                description: 'Enable/disable MU compounded report.'
                choices:
                    - 'disable'
                    - 'enable'
            aeroscout-mu:
                type: str
                description: 'Enable/disable AeroScout support.'
                choices:
                    - 'disable'
                    - 'enable'
            aeroscout-mu-factor:
                type: int
                description: 'AeroScout Mobile Unit (MU) mode dilution factor (default = 20).'
            aeroscout-mu-timeout:
                type: int
                description: 'AeroScout MU mode timeout (0 - 65535 sec, default = 5).'
            aeroscout-server-ip:
                type: str
                description: 'IP address of AeroScout server.'
            aeroscout-server-port:
                type: int
                description: 'AeroScout server UDP listening port.'
            ekahau-blink-mode:
                type: str
                description: 'Enable/disable Ekahua blink mode (also called AiRISTA Flow Blink Mode) to find the location of devices connected to a wireless...'
                choices:
                    - 'disable'
                    - 'enable'
            ekahau-tag:
                type: str
                description: 'WiFi frame MAC address or WiFi Tag.'
            erc-server-ip:
                type: str
                description: 'IP address of Ekahua RTLS Controller (ERC).'
            erc-server-port:
                type: int
                description: 'Ekahua RTLS Controller (ERC) UDP listening port.'
            fortipresence:
                type: str
                description: 'Enable/disable FortiPresence to monitor the location and activity of WiFi clients even if they dont connect to this WiFi netwo...'
                choices:
                    - 'disable'
                    - 'enable'
                    - 'enable2'
                    - 'foreign'
                    - 'both'
            fortipresence-frequency:
                type: int
                description: 'FortiPresence report transmit frequency (5 - 65535 sec, default = 30).'
            fortipresence-port:
                type: int
                description: 'FortiPresence server UDP listening port (default = 3000).'
            fortipresence-project:
                type: str
                description: 'FortiPresence project name (max. 16 characters, default = fortipresence).'
            fortipresence-rogue:
                type: str
                description: 'Enable/disable FortiPresence finding and reporting rogue APs.'
                choices:
                    - 'disable'
                    - 'enable'
            fortipresence-secret:
                description: no description
                type: str
            fortipresence-server:
                type: str
                description: 'FortiPresence server IP address.'
            fortipresence-unassoc:
                type: str
                description: 'Enable/disable FortiPresence finding and reporting unassociated stations.'
                choices:
                    - 'disable'
                    - 'enable'
            station-locate:
                type: str
                description: 'Enable/disable client station locating services for all clients, whether associated or not (default = disable).'
                choices:
                    - 'disable'
                    - 'enable'

'''

EXAMPLES = '''
 - hosts: fortimanager-inventory
   collections:
     - fortinet.fortimanager
   connection: httpapi
   vars:
      ansible_httpapi_use_ssl: True
      ansible_httpapi_validate_certs: False
      ansible_httpapi_port: 443
   tasks:
    - name: Set various location based service (LBS) options.
      fmgr_wtpprofile_lbs:
         bypass_validation: False
         workspace_locking_adom: <value in [global, custom adom including root]>
         workspace_locking_timeout: 300
         rc_succeeded: [0, -2, -3, ...]
         rc_failed: [-2, -3, ...]
         adom: <your own value>
         wtp-profile: <your own value>
         wtpprofile_lbs:
            aeroscout: <value in [disable, enable]>
            aeroscout-ap-mac: <value in [bssid, board-mac]>
            aeroscout-mmu-report: <value in [disable, enable]>
            aeroscout-mu: <value in [disable, enable]>
            aeroscout-mu-factor: <value of integer>
            aeroscout-mu-timeout: <value of integer>
            aeroscout-server-ip: <value of string>
            aeroscout-server-port: <value of integer>
            ekahau-blink-mode: <value in [disable, enable]>
            ekahau-tag: <value of string>
            erc-server-ip: <value of string>
            erc-server-port: <value of integer>
            fortipresence: <value in [disable, enable, enable2, ...]>
            fortipresence-frequency: <value of integer>
            fortipresence-port: <value of integer>
            fortipresence-project: <value of string>
            fortipresence-rogue: <value in [disable, enable]>
            fortipresence-secret: <value of string>
            fortipresence-server: <value of string>
            fortipresence-unassoc: <value in [disable, enable]>
            station-locate: <value in [disable, enable]>

'''

RETURN = '''
request_url:
    description: The full url requested
    returned: always
    type: str
    sample: /sys/login/user
response_code:
    description: The status of api request
    returned: always
    type: int
    sample: 0
response_message:
    description: The descriptive message of the api response
    type: str
    returned: always
    sample: OK.

'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass


def main():
    jrpc_urls = [
        '/pm/config/adom/{adom}/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs',
        '/pm/config/global/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs'
    ]

    perobject_jrpc_urls = [
        '/pm/config/adom/{adom}/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs/{lbs}',
        '/pm/config/global/obj/wireless-controller/wtp-profile/{wtp-profile}/lbs/{lbs}'
    ]

    url_params = ['adom', 'wtp-profile']
    module_primary_key = None
    module_arg_spec = {
        'enable_log': {
            'type': 'bool',
            'required': False,
            'default': False
        },
        'proposed_method': {
            'type': 'str',
            'required': False,
            'choices': [
                'set',
                'update',
                'add'
            ]
        },
        'bypass_validation': {
            'type': 'bool',
            'required': False,
            'default': False
        },
        'workspace_locking_adom': {
            'type': 'str',
            'required': False
        },
        'workspace_locking_timeout': {
            'type': 'int',
            'required': False,
            'default': 300
        },
        'rc_succeeded': {
            'required': False,
            'type': 'list'
        },
        'rc_failed': {
            'required': False,
            'type': 'list'
        },
        'adom': {
            'required': True,
            'type': 'str'
        },
        'wtp-profile': {
            'required': True,
            'type': 'str'
        },
        'wtpprofile_lbs': {
            'required': False,
            'type': 'dict',
            'options': {
                'aeroscout': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'aeroscout-ap-mac': {
                    'required': False,
                    'choices': [
                        'bssid',
                        'board-mac'
                    ],
                    'type': 'str'
                },
                'aeroscout-mmu-report': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'aeroscout-mu': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'aeroscout-mu-factor': {
                    'required': False,
                    'type': 'int'
                },
                'aeroscout-mu-timeout': {
                    'required': False,
                    'type': 'int'
                },
                'aeroscout-server-ip': {
                    'required': False,
                    'type': 'str'
                },
                'aeroscout-server-port': {
                    'required': False,
                    'type': 'int'
                },
                'ekahau-blink-mode': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'ekahau-tag': {
                    'required': False,
                    'type': 'str'
                },
                'erc-server-ip': {
                    'required': False,
                    'type': 'str'
                },
                'erc-server-port': {
                    'required': False,
                    'type': 'int'
                },
                'fortipresence': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable',
                        'enable2',
                        'foreign',
                        'both'
                    ],
                    'type': 'str'
                },
                'fortipresence-frequency': {
                    'required': False,
                    'type': 'int'
                },
                'fortipresence-port': {
                    'required': False,
                    'type': 'int'
                },
                'fortipresence-project': {
                    'required': False,
                    'type': 'str'
                },
                'fortipresence-rogue': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'fortipresence-secret': {
                    'required': False,
                    'type': 'str'
                },
                'fortipresence-server': {
                    'required': False,
                    'type': 'str'
                },
                'fortipresence-unassoc': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                },
                'station-locate': {
                    'required': False,
                    'choices': [
                        'disable',
                        'enable'
                    ],
                    'type': 'str'
                }
            }

        }
    }

    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'wtpprofile_lbs'),
                           supports_check_mode=False)

    fmgr = None
    if module._socket_path:
        connection = Connection(module._socket_path)
        connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
        fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
        fmgr.validate_parameters(params_validation_blob)
        fmgr.process_partial_curd()
    else:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
